ExAzureCore.Auth.FederatedTokenProvider behaviour (ex_azure_core v0.1.0)
Copy MarkdownBehaviour and dispatcher for federated identity token providers.
Provides a unified interface for obtaining tokens from various federated identity providers such as AWS Cognito.
Summary
Callbacks
Defines the callback for retrieving a federated identity token.
Functions
Retrieves a federated identity token from the specified provider.